@@ -1,19 +1,21 @@
-from allib.stopcriterion.base import AbstractStopCriterion
-from allib.estimation.base import AbstractEstimator
 from typing import Any, Callable, Dict
+
 import numpy as np
 
-from ..stopcriterion.estimation import CombinedStopCriterion, UpperboundCombinedCritertion
-from ..stopcriterion.catalog import StopCriterionCatalog
+from ..estimation.base import AbstractEstimator
+from ..estimation.rasch_comb_parametric import EMRaschRidgeParametricPython
 from ..estimation.rasch_parametric import ParametricRaschPython
 from ..estimation.rasch_python import EMRaschRidgePython
-from .catalog import ALConfiguration, FEConfiguration, EstimationConfiguration
+from ..stopcriterion.base import AbstractStopCriterion
+from ..stopcriterion.catalog import StopCriterionCatalog
+from ..stopcriterion.estimation import (CombinedStopCriterion,
+                                        UpperboundCombinedCritertion)
+from ..typehints import LT
+from .catalog import ALConfiguration, EstimationConfiguration, FEConfiguration
 from .ensemble import (al_config_ensemble_prob, al_config_entropy,
                        naive_bayes_estimator, rasch_estimator, rasch_lr,
                        rasch_rf, svm_estimator, tf_idf5000)
 
-from ..typehints import LT
-
 AL_REPOSITORY = {
     ALConfiguration.NaiveBayesEstimator :  naive_bayes_estimator,
     ALConfiguration.SVMEstimator : svm_estimator,
@@ -31,6 +33,7 @@ FE_REPOSITORY = {
 ESTIMATION_REPOSITORY = {
     EstimationConfiguration.RaschRidge: EMRaschRidgePython[int, str, np.ndarray, str, str](),
     EstimationConfiguration.RaschParametric: ParametricRaschPython[int, str, np.ndarray, str, str](),
+    EstimationConfiguration.RaschApproxParametric: EMRaschRidgeParametricPython[int, str, np.ndarray, str, str](),
 }
 
 STOP_REPOSITORY: Dict[StopCriterionCatalog, Callable[[AbstractEstimator, Any], AbstractStopCriterion]] = {
